==> Compositional_2.3.tar.gz: Compositional/R/mix.compnorm.R <==
################################
#### Normal mixture models for compositional data
#### Tsagris Michail 5/2015
#### mtsagris@yahoo.gr
#### References: Ryan P. Browne, Aisha ElSherbiny and
#### Paul D. McNicholas (2015)
#### R package mixture: Mixture Models for Clustering and Classification
################################

mix.compnorm <- function(x, g, model, type = "alr") {
  ## x is the compositional data
  ## g is the number of components to be used
  ## model is the type of model to be used
  ## type is either 'alr' or 'ilr'
  p <- dim(x)[2]  ## dimensionality of the data
  n <- dim(x)[1]  ## sample size

  if (type == "alr") {
    y <- log(x[, -p]/x[, p])
  } else {
    y0 <- log(x)
    y1 <- y0 - Rfast::rowmeans( y0 )
    y <- tcrossprod( y1, helm(p) )
  }

  mod <- mixture::gpcm(y, G = g, mnames = model, start = 0, atol = 0.01)
  param <- mod$gpar
  mu <- matrix(nrow = g, ncol = length(param[[1]]$mu))
  su <- array( dim = c( length(param[[1]]$mu), length(param[[1]]$mu), g ) )

  for ( i in 1:g ) {
    mu[i, ] <- param[[ i ]]$mu  ## mean vector of each component
    su[, , i] <- param[[ i ]]$sigma  ## covariance of each component
  }
  prob <- param$pi  ## mixing probability of each component
  colnames(mu) <- colnames(su) <- colnames(y)
  ta <- matrix(nrow = n, ncol = g)

  for (j in 1:g) {
    ta[, j] <-  - 0.5 * log( det(2 * pi * su[, , j]) ) -
      0.5 * Rfast::mahala(y, mu[j, ], su[, , j])
  }

  probexpta <- prob * exp(ta)
  pij <- probexpta / Rfast::rowsums(probexpta)
  est <- Rfast::rowMaxs(pij)

  list(type = type, mu = mu, su = su, prob = prob, est = est)
}

==> Compositional_2.5.tar.gz: Compositional/R/mix.compnorm.R <==
################################
#### Normal mixture models for compositional data
#### Tsagris Michail 5/2015
#### mtsagris@yahoo.gr
#### References: Ryan P. Browne, Aisha ElSherbiny and
#### Paul D. McNicholas (2015)
#### R package mixture: Mixture Models for Clustering and Classification
################################
mix.compnorm <- function(x, g, model, type = "alr") {
  ## x is the compositional data
  ## g is the number of components to be used
  ## model is the type of model to be used
  ## type is either 'alr' or 'ilr'
  p <- dim(x)[2]  ## dimensionality of the data
  n <- dim(x)[1]  ## sample size

  if (type == "alr") {
    y <- log(x[, -p]/x[, p])
  } else {
    y0 <- log(x)
    y1 <- y0 - Rfast::rowmeans( y0 )
    y <- tcrossprod( y1, helm(p) )
  }

  mod <- mixture::gpcm(y, G = g, mnames = model, start = 0, atol = 0.01)
  param <- mod$gpar
  mu <- matrix(nrow = g, ncol = length(param[[1]]$mu))
  su <- array( dim = c( length(param[[1]]$mu), length(param[[1]]$mu), g ) )

  for ( i in 1:g ) {
    mu[i, ] <- param[[ i ]]$mu  ## mean vector of each component
    su[, , i] <- param[[ i ]]$sigma  ## covariance of each component
  }
  prob <- param$pi  ## mixing probability of each component
  colnames(mu) <- colnames(su) <- colnames(y)
  ta <- matrix(nrow = n, ncol = g)
  for (j in 1:g)   ta[, j] <-  - 0.5 * log( det(2 * pi * su[, , j]) ) - 0.5 * Rfast::mahala(y, mu[j, ], su[, , j])
  probexpta <- prob * exp(ta)
  pij <- probexpta / Rfast::rowsums(probexpta)
  est <- Rfast::rowMaxs(pij)
  list(type = type, mu = mu, su = su, prob = prob, est = est)
}
